==> pcsxr-1.9.83.tar.bz2: pcsxr/win32/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by pcsx.rc
//
#define IDS_TITLE                       1
#define IDC_SEARCHFOR                   100
#define IDR_MENU1                       101
#define IDI_APP_ICON                    102
#define IDD_MCDCONF                     102
#define DEBUG_DIALOG                    103
#define IDC_VALUEFROM                   103
#define ABOUT_DIALOG                    104
#define IDC_LABEL_TO                    104
#define IDD_CPUCONF                     105
#define IDC_VALUETO                     105
#define IDC_DATATYPE                    106
#define IDC_DATABASE                    107
#define IDD_NETPLAY                     108
#define IDC_LABEL_RESULTSFOUND          108
#define IDD_CONNECT                     109
#define IDC_RESLIST                     109
#define IDD_CHEATLIST                   110
#define IDC_SEARCH                      110
#define IDC_NEWSEARCH                   111
#define IDD_CHEATSEARCH                 112
#define SPLASH_LOGO                     113
#define IDC_MODIFY                      113
#define IDD_GPREGS                      114
#define IDC_FREEZE                      114
#define IDD_CHEATEDIT                   114
#define IDD_CP0REGS                     115
#define IDC_COPY                        115
#define IDD_CHEATVALEDIT                115
#define IDD_COP2D                       116
#define IDD_COP2C                       117
#define MAIN_LOGO                       118
#define IDD_CONFIG                      120
#define IDD_MEMVIEW                     136
#define IDC_EDIT2                       1001
#define IDC_CODE                        1001
#define IDC_VALUE                       1001
#define IDC_MCD2                        1004
#define IDC_ASMCHECK1                   1005
#define IDC_MCD1                        1005
#define IDC_MCDSEL1                     1006
#define IDC_STEP                        1007
#define IDC_MCDSEL2                     1007
#define IDC_XA                          1007
#define IDC_SIO                         1008
#define IDC_SKIP                        1009
#define IDC_MDEC                        1009
#define IDC_RESET                       1010
#define IDC_PSXAUTO                     1010
#define IDC_GO                          1011
#define IDC_PSXTYPES                    1011
#define IDC_BREAK                       1012
#define IDC_DISCPUQKEYS                 1012
#define IDC_QKEYS                       1012
#define IDC_EDIT1                       1013
#define IDC_CDDA                        1013
#define IDC_DESCR                       1013
#define IDC_ADDRESS                     1013
#define IDC_CLOSE                       1014
#define IDC_PCSX_ABOUT_TEXT             1014
#define IDC_PSXOUT                      1014
#define IDC_ASM_SCROLL                  1015
#define IDC_CPU                         1015
#define IDC_ASMCHECK2                   1016
#define IDC_SPUIRQ                      1016
#define IDC_ASMCHECK3                   1017
#define IDC_MDEC2                       1017
#define IDC_CDTIMING                    1017
#define IDC_ASMCHECK4                   1018
#define IDC_ASMCHECK5                   1019
#define IDC_RELOAD1                     1019
#define IDC_CP07                        1020
#define IDC_ASMCHECK6                   1020
#define IDC_RELOAD2                     1020
#define IDC_ASMCHECK7                   1021
#define IDC_COPYTO2                     1021
#define IDC_ASMCHECK8                   1022
#define IDC_COPYTO1                     1022
#define IDC_RCNTFIX                     1022
#define IDC_ASMCHECK9                   1023
#define IDC_PASTE                       1023
#define IDC_CONFIGNET                   1023
#define IDC_VSYNCWA                     1023
#define IDC_ASMCHECK10                  1024
#define IDC_DELETE1                     1024
#define IDC_TESTNET                     1024
#define IDC_ASMCHECK11                  1025
#define IDC_DELETE2                     1025
#define IDC_ABOUTNET                    1025
#define IDC_ASMCHECK12                  1026
#define IDC_LISTNET                     1026
#define IDC_LIST1                       1027
#define IDC_ASMCHECK13                  1027
#define IDC_SYSCMCDS                    1027
#define IDC_ASMCHECK14                  1028
#define IDC_LIST2                       1028
#define IDC_CONNECTSTR                  1028
#define IDC_ASMCHECK15                  1029
#define IDC_PCSX_ABOUT_AUTHORS          1029
#define IDC_ASMCHECK16                  1030
#define IDC_PCSX_ABOUT_GREETS           1030
#define IDC_ASMCHECK17                  1031
#define IDC_SELPSX                      1031
#define IDC_ASMCHECK18                  1032
#define IDC_MISCOPT                     1032
#define IDC_ASMCHECK19                  1033
#define IDC_GRAPHICS                    1033
#define IDC_CP021                       1034
#define IDC_ASMCHECK20                  1034
#define IDC_FIRSTCONTROLLER             1034
#define IDC_CP022                       1035
#define IDC_ASMCHECK21                  1035
#define IDC_SECONDCONTROLLER            1035
#define IDC_CP023                       1036
#define IDC_ASMCHECK22                  1036
#define IDC_SOUND                       1036
#define IDC_CP024                       1037
#define IDC_ASMCHECK23                  1037
#define IDC_CDROM                       1037
#define IDC_CP025                       1038
#define IDC_ASMCHECK24                  1038
#define IDC_BIOS                        1038
#define IDC_NETPLAY                     1039
#define IDC_NETPLAYNOTE                 1040
#define IDC_FRAMEMCD1                   1041
#define IDC_FRAMEMCD2                   1042
#define IDC_CP031                       1044
#define IDC_CODELIST                    1044
#define IDC_REMOVECODE                  1045
#define IDC_EDITCODE                    1046
#define IDC_GPR0                        1047
#define IDC_TOGGLECODE                  1047
#define IDC_GPR1                        1048
#define IDC_SAVECODE                    1048
#define IDC_GPR2                        1049
#define IDC_LOADCODE                    1049
#define IDC_GPR3                        1050
#define IDC_LABEL_DESCR                 1050
#define IDC_GPR4                        1051
#define IDC_LABEL_CODE                  1051
#define IDC_GPR5                        1052
#define IDC_LISTGPU                     1052
#define IDC_LABEL_ADDRESS               1052
#define IDC_GPR6                        1053
#define IDC_LISTSPU                     1053
#define IDC_GPR7                        1054
#define IDC_LISTCDR                     1054
#define IDC_GPR8                        1055
#define IDC_LISTBIOS                    1055
#define IDC_GPR9                        1056
#define IDC_CONFIGGPU                   1056
#define IDC_GPR10                       1057
#define IDC_TESTGPU                     1057
#define IDC_ABOUTGPU                    1058
#define IDC_CONFIGSPU                   1059
#define IDC_TESTSPU                     1060
#define IDC_ABOUTSPU                    1061
#define IDC_CONFIGCDR                   1062
#define IDC_GPR11                       1063
#define IDC_TESTCDR                     1063
#define IDC_ABOUTCDR                    1064
#define IDC_COMBODRIVE                  1065
#define IDC_LISTPAD1                    1066
#define IDC_CONFIGPAD1                  1067
#define IDC_GPR12                       1068
#define IDC_TESTPAD1                    1068
#define IDC_GPR13                       1069
#define IDC_ABOUTPAD1                   1069
#define IDC_GPR14                       1070
#define IDC_LISTPAD2                    1070
#define IDC_GPR15                       1071
#define IDC_CONFIGPAD2                  1071
#define IDC_GPR16                       1072
#define IDC_TESTPAD2                    1072
#define IDC_GPR17                       1073
#define IDC_ABOUTPAD2                   1073
#define IDC_GPR18                       1074
#define IDC_GPR19                       1075
#define IDC_GPR20                       1076
#define IDC_GPR21                       1077
#define IDC_GPR22                       1078
#define IDC_GPR23                       1079
#define IDC_GPR24                       1080
#define IDC_GPR25                       1081
#define IDC_GPR26                       1082
#define IDC_GPR27                       1083
#define IDC_GPR28                       1084
#define IDC_GPR29                       1085
#define IDC_GPR30                       1086
#define IDC_GPR31                       1087
#define IDC_GPR_PC                      1089
#define IDC_GPR_HI                      1091
#define IDC_GPR_LO                      1092
#define IDC_CP00                        1093
#define IDC_CP01                        1094
#define IDC_CP02                        1095
#define IDC_CP03                        1096
#define IDC_CP04                        1097
#define IDC_CP05                        1098
#define IDC_CP06                        1099
#define IDC_CP08                        1100
#define IDC_CP09                        1101
#define IDC_CP010                       1102
#define IDC_CP011                       1103
#define IDC_CP012                       1104
#define IDC_CP013                       1105
#define IDC_CP014                       1106
#define IDC_CP015                       1107
#define IDC_CP016                       1108
#define IDC_CP017                       1109
#define IDC_CP018                       1110
#define IDC_CP019                       1111
#define IDC_CP020                       1112
#define IDC_CP026                       1113
#define IDC_CP027                       1114
#define IDC_CP028                       1115
#define IDC_CP029                       1116
#define IDC_CP030                       1117
#define IDC_COP2D0                      1118
#define IDC_COP2D1                      1119
#define IDC_COP2D2                      1120
#define IDC_COP2D3                      1121
#define IDC_COP2D4                      1122
#define IDC_COP2D5                      1123
#define IDC_COP2D6                      1124
#define IDC_COP2D7                      1125
#define IDC_COP2D8                      1126
#define IDC_COP2D9                      1127
#define IDC_COP2D10                     1128
#define IDC_COP2D11                     1129
#define IDC_COP2D12                     1130
#define IDC_COP2D13                     1131
#define IDC_COP2D14                     1132
#define IDC_COP2D15                     1133
#define IDC_COP2D16                     1134
#define IDC_COP2D17                     1135
#define IDC_COP2D18                     1136
#define IDC_COP2D19                     1137
#define IDC_COP2D20                     1138
#define IDC_COP2D21                     1139
#define IDC_COP2D22                     1140
#define IDC_COP2D23                     1141
#define IDC_COP2D24                     1142
#define IDC_COP2D25                     1143
#define IDC_COP2D26                     1144
#define IDC_COP2D27                     1145
#define IDC_COP2D28                     1146
#define IDC_COP2D29                     1147
#define IDC_COP2D30                     1148
#define IDC_COP2D31                     1149
#define IDC_COP2C0                      1152
#define IDC_COP2C1                      1153
#define IDC_COP2C2                      1154
#define IDC_COP2C3                      1155
#define IDC_COP2C4                      1156
#define IDC_COP2C5                      1157
#define IDC_COP2C6                      1158
#define IDC_COP2C7                      1159
#define IDC_COP2C8                      1160
#define IDC_COP2C9                      1161
#define IDC_COP2C10                     1162
#define IDC_COP2C11                     1163
#define IDC_COP2C12                     1164
#define IDC_COP2C13                     1165
#define IDC_COP2C14                     1166
#define IDC_COP2C15                     1167
#define IDC_COP2C16                     1168
#define IDC_COP2C17                     1169
#define IDC_COP2C18                     1170
#define IDC_COP2C19                     1171
#define IDC_COP2C20                     1172
#define IDC_COP2C21                     1173
#define IDC_COP2C22                     1174
#define IDC_COP2C23                     1175
#define IDC_COP2C24                     1176
#define IDC_COP2C25                     1177
#define IDC_COP2C26                     1178
#define IDC_COP2C27                     1179
#define IDC_COP2C28                     1180
#define IDC_COP2C29                     1181
#define IDC_COP2C30                     1182
#define IDC_COP2C31                     1183
#define IDC_BUTTON1                     1254
#define IDC_BIOSDIR                     1254
#define IDC_FORMAT1                     1254
#define IDC_ADDCODE                     1254
#define IDC_PLUGINSDIR                  1255
#define IDC_FORMAT2                     1255
#define IDC_LABEL_DATATYPE              1260
#define IDC_LABEL_SEARCHFOR             1261
#define IDC_LABEL_VALUE                 1262
#define IDC_LABEL_DATABASE              1263
#define ID_FILE_EXIT                    40001
#define ID_HELP_ABOUT                   40002
#define ID_FILE_RUN_CD                  40003
#define ID_FILE_RUN_EXE                 40004
#define ID_EMULATOR_PAUSE               40005
#define ID_EMULATOR_RESET               40006
#define ID_FILE_RUN_ISO                 40007
#define ID_DEBUG_ENABLE_DEBUGGER        40008
#define ID_CONFIGURATION_GRAPHICS       40009
#define ID_CONFIGURATION_SOUND          40010
#define ID_CONFIGURATION_CDROM          40011
#define ID_CONFIGURATION_MEMORYCARDMANAGER 40012
#define ID_CONFIGURATION_CPU            40013
#define ID_EMULATOR_RUN                 40014
#define ID_DEBUGREG                     40015
#define ID_DEBUG_MESSAGES               40015
#define ID_CONFIGURATION_CONTROLLERS    40017
#define ID_CONFIGURATION                40018
#define ID_FILE_RUNBIOS                 40026
#define ID_FILE_STATES_LOAD_SLOT1       40031
#define ID_FILE_STATES_LOAD_SLOT2       40032
#define ID_FILE_STATES_LOAD_SLOT3       40033
#define ID_FILE_STATES_LOAD_SLOT4       40034
#define ID_FILE_STATES_LOAD_SLOT5       40035
#define ID_FILE_STATES_LOAD_OTHER       40036
#define ID_FILE_STATES_SAVE_SLOT1       40037
#define ID_FILE_STATES_SAVE_SLOT2       40038
#define ID_FILE_STATES_SAVE_SLOT3       40039
#define ID_FILE_STATES_SAVE_SLOT4       40040
#define ID_FILE_STATES_SAVE_SLOT5       40041
#define ID_FILE_STATES_SAVE_OTHER       40042
#define ID_CONFIGURATION_NETPLAY        40043
#define ID_EMULATOR_SWITCH_ISO          40044
#define ID_CONFIGURATION_CHEATLIST      40045
#define ID_CONFIGURATION_CHEATSEARCH    40046
#define ID_LANGS                        50000

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        116
#define _APS_NEXT_COMMAND_VALUE         40047
#define _APS_NEXT_CONTROL_VALUE         1053
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> pcsxr-1.9.93.tar.bz2: pcsxr/win32/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by pcsxr.rc
//
#define IDS_TITLE                       1
#define IDC_SEARCHFOR                   100
#define IDR_MENU1                       101
#define IDI_APP_ICON                    102
#define IDD_MCDCONF                     102
#define DEBUG_DIALOG                    103
#define IDC_VALUEFROM                   103
#define ABOUT_DIALOG                    104
#define IDC_LABEL_TO                    104
#define IDD_CPUCONF                     105
#define IDC_VALUETO                     105
#define IDC_DATATYPE                    106
#define IDC_DATABASE                    107
#define IDD_NETPLAY                     108
#define IDC_LABEL_RESULTSFOUND          108
#define IDD_CONNECT                     109
#define IDC_RESLIST                     109
#define IDD_CHEATLIST                   110
#define IDC_SEARCH                      110
#define IDC_NEWSEARCH                   111
#define IDD_CHEATSEARCH                 112
#define SPLASH_LOGO                     113
#define IDC_MODIFY                      113
#define IDD_GPREGS                      114
#define IDC_FREEZE                      114
#define IDD_CHEATEDIT                   114
#define IDD_CP0REGS                     115
#define IDC_COPY                        115
#define IDD_CHEATVALEDIT                115
#define IDD_COP2D                       116
#define IDD_COP2C                       117
#define MAIN_LOGO                       118
#define IDD_CONFIG                      120
#define IDD_MEMVIEW                     136
#define IDC_EDIT2                       1001
#define IDC_CODE                        1001
#define IDC_VALUE                       1001
#define IDC_MCD2                        1004
#define IDC_ASMCHECK1                   1005
#define IDC_MCD1                        1005
#define IDC_MCDSEL1                     1006
#define IDC_STEP                        1007
#define IDC_MCDSEL2                     1007
#define IDC_XA                          1007
#define IDC_SIO                         1008
#define IDC_SKIP                        1009
#define IDC_MDEC                        1009
#define IDC_RESET                       1010
#define IDC_PSXAUTO                     1010
#define IDC_GO                          1011
#define IDC_PSXTYPES                    1011
#define IDC_BREAK                       1012
#define IDC_DISCPUQKEYS                 1012
#define IDC_QKEYS                       1012
#define IDC_EDIT1                       1013
#define IDC_CDDA                        1013
#define IDC_DESCR                       1013
#define IDC_ADDRESS                     1013
#define IDC_CLOSE                       1014
#define IDC_PCSXR_ABOUT_TEXT            1014
#define IDC_PSXOUT                      1014
#define IDC_ASM_SCROLL                  1015
#define IDC_CPU                         1015
#define IDC_ASMCHECK2                   1016
#define IDC_SPUIRQ                      1016
#define IDC_ASMCHECK3                   1017
#define IDC_MDEC2                       1017
#define IDC_CDTIMING                    1017
#define IDC_SLOWBOOT                    1017
#define IDC_ASMCHECK4                   1018
#define IDC_ASMCHECK5                   1019
#define IDC_RELOAD1                     1019
#define IDC_CP07                        1020
#define IDC_ASMCHECK6                   1020
#define IDC_RELOAD2                     1020
#define IDC_ASMCHECK7                   1021
#define IDC_COPYTO2                     1021
#define IDC_ASMCHECK8                   1022
#define IDC_COPYTO1                     1022
#define IDC_RCNTFIX                     1022
#define IDC_ASMCHECK9                   1023
#define IDC_PASTE                       1023
#define IDC_CONFIGNET                   1023
#define IDC_VSYNCWA                     1023
#define IDC_ASMCHECK10                  1024
#define IDC_DELETE1                     1024
#define IDC_TESTNET                     1024
#define IDC_ASMCHECK11                  1025
#define IDC_DELETE2                     1025
#define IDC_ABOUTNET                    1025
#define IDC_ASMCHECK12                  1026
#define IDC_LISTNET                     1026
#define IDC_LIST1                       1027
#define IDC_ASMCHECK13                  1027
#define IDC_SYSCMCDS                    1027
#define IDC_ASMCHECK14                  1028
#define IDC_LIST2                       1028
#define IDC_CONNECTSTR                  1028
#define IDC_ASMCHECK15                  1029
#define IDC_PCSXR_ABOUT_AUTHORS         1029
#define IDC_ASMCHECK16                  1030
#define IDC_PCSXR_ABOUT_GREETS          1030
#define IDC_ASMCHECK17                  1031
#define IDC_SELPSX                      1031
#define IDC_ASMCHECK18                  1032
#define IDC_MISCOPT                     1032
#define IDC_ASMCHECK19                  1033
#define IDC_GRAPHICS                    1033
#define IDC_CP021                       1034
#define IDC_ASMCHECK20                  1034
#define IDC_FIRSTCONTROLLER             1034
#define IDC_CP022                       1035
#define IDC_ASMCHECK21                  1035
#define IDC_SECONDCONTROLLER            1035
#define IDC_CP023                       1036
#define IDC_ASMCHECK22                  1036
#define IDC_SOUND                       1036
#define IDC_CP024                       1037
#define IDC_ASMCHECK23                  1037
#define IDC_CDROM                       1037
#define IDC_CP025                       1038
#define IDC_ASMCHECK24                  1038
#define IDC_BIOS                        1038
#define IDC_NETPLAY                     1039
#define IDC_LINKCABLE                   1039
#define IDC_NETPLAYNOTE                 1040
#define IDC_FRAMEMCD1                   1041
#define IDC_FRAMEMCD2                   1042
#define IDC_CP031                       1044
#define IDC_CODELIST                    1044
#define IDC_REMOVECODE                  1045
#define IDC_EDITCODE                    1046
#define IDC_GPR0                        1047
#define IDC_TOGGLECODE                  1047
#define IDC_GPR1                        1048
#define IDC_SAVECODE                    1048
#define IDC_GPR2                        1049
#define IDC_LOADCODE                    1049
#define IDC_GPR3                        1050
#define IDC_LABEL_DESCR                 1050
#define IDC_GPR4                        1051
#define IDC_LABEL_CODE                  1051
#define IDC_GPR5                        1052
#define IDC_LISTGPU                     1052
#define IDC_LABEL_ADDRESS               1052
#define IDC_GPR6                        1053
#define IDC_LISTSPU                     1053
#define IDC_DEBUG                       1053
#define IDC_GPR7                        1054
#define IDC_LISTCDR                     1054
#define IDC_GPR8                        1055
#define IDC_LISTBIOS                    1055
#define IDC_GPR9                        1056
#define IDC_CONFIGGPU                   1056
#define IDC_GPR10                       1057
#define IDC_TESTGPU                     1057
#define IDC_ABOUTGPU                    1058
#define IDC_CONFIGSPU                   1059
#define IDC_TESTSPU                     1060
#define IDC_ABOUTSPU                    1061
#define IDC_CONFIGCDR                   1062
#define IDC_GPR11                       1063
#define IDC_TESTCDR                     1063
#define IDC_ABOUTCDR                    1064
#define IDC_COMBODRIVE                  1065
#define IDC_LISTSIO1                    1065
#define IDC_LISTPAD1                    1066
#define IDC_CONFIGPAD1                  1067
#define IDC_GPR12                       1068
#define IDC_TESTPAD1                    1068
#define IDC_GPR13                       1069
#define IDC_ABOUTPAD1                   1069
#define IDC_GPR14                       1070
#define IDC_LISTPAD2                    1070
#define IDC_GPR15                       1071
#define IDC_CONFIGPAD2                  1071
#define IDC_GPR16                       1072
#define IDC_TESTPAD2                    1072
#define IDC_GPR17                       1073
#define IDC_ABOUTPAD2                   1073
#define IDC_GPR18                       1074
#define IDC_CONFIGSIO1                  1074
#define IDC_GPR19                       1075
#define IDC_TESTSIO1                    1075
#define IDC_GPR20                       1076
#define IDC_ABOUTCDR2                   1076
#define IDC_ABOUTSIO1                   1076
#define IDC_GPR21                       1077
#define IDC_GPR22                       1078
#define IDC_GPR23                       1079
#define IDC_GPR24                       1080
#define IDC_GPR25                       1081
#define IDC_GPR26                       1082
#define IDC_GPR27                       1083
#define IDC_GPR28                       1084
#define IDC_GPR29                       1085
#define IDC_GPR30                       1086
#define IDC_GPR31                       1087
#define IDC_GPR_PC                      1089
#define IDC_GPR_HI                      1091
#define IDC_GPR_LO                      1092
#define IDC_CP00                        1093
#define IDC_CP01                        1094
#define IDC_CP02                        1095
#define IDC_CP03                        1096
#define IDC_CP04                        1097
#define IDC_CP05                        1098
#define IDC_CP06                        1099
#define IDC_CP08                        1100
#define IDC_CP09                        1101
#define IDC_CP010                       1102
#define IDC_CP011                       1103
#define IDC_CP012                       1104
#define IDC_CP013                       1105
#define IDC_CP014                       1106
#define IDC_CP015                       1107
#define IDC_CP016                       1108
#define IDC_CP017                       1109
#define IDC_CP018                       1110
#define IDC_CP019                       1111
#define IDC_CP020                       1112
#define IDC_CP026                       1113
#define IDC_CP027                       1114
#define IDC_CP028                       1115
#define IDC_CP029                       1116
#define IDC_CP030                       1117
#define IDC_COP2D0                      1118
#define IDC_COP2D1                      1119
#define IDC_COP2D2                      1120
#define IDC_COP2D3                      1121
#define IDC_COP2D4                      1122
#define IDC_COP2D5                      1123
#define IDC_COP2D6                      1124
#define IDC_COP2D7                      1125
#define IDC_COP2D8                      1126
#define IDC_COP2D9                      1127
#define IDC_COP2D10                     1128
#define IDC_COP2D11                     1129
#define IDC_COP2D12                     1130
#define IDC_COP2D13                     1131
#define IDC_COP2D14                     1132
#define IDC_COP2D15                     1133
#define IDC_COP2D16                     1134
#define IDC_COP2D17                     1135
#define IDC_COP2D18                     1136
#define IDC_COP2D19                     1137
#define IDC_COP2D20                     1138
#define IDC_COP2D21                     1139
#define IDC_COP2D22                     1140
#define IDC_COP2D23                     1141
#define IDC_COP2D24                     1142
#define IDC_COP2D25                     1143
#define IDC_COP2D26                     1144
#define IDC_COP2D27                     1145
#define IDC_COP2D28                     1146
#define IDC_COP2D29                     1147
#define IDC_COP2D30                     1148
#define IDC_COP2D31                     1149
#define IDC_COP2C0                      1152
#define IDC_COP2C1                      1153
#define IDC_COP2C2                      1154
#define IDC_COP2C3                      1155
#define IDC_COP2C4                      1156
#define IDC_COP2C5                      1157
#define IDC_COP2C6                      1158
#define IDC_COP2C7                      1159
#define IDC_COP2C8                      1160
#define IDC_COP2C9                      1161
#define IDC_COP2C10                     1162
#define IDC_COP2C11                     1163
#define IDC_COP2C12                     1164
#define IDC_COP2C13                     1165
#define IDC_COP2C14                     1166
#define IDC_COP2C15                     1167
#define IDC_COP2C16                     1168
#define IDC_COP2C17                     1169
#define IDC_COP2C18                     1170
#define IDC_COP2C19                     1171
#define IDC_COP2C20                     1172
#define IDC_COP2C21                     1173
#define IDC_COP2C22                     1174
#define IDC_COP2C23                     1175
#define IDC_COP2C24                     1176
#define IDC_COP2C25                     1177
#define IDC_COP2C26                     1178
#define IDC_COP2C27                     1179
#define IDC_COP2C28                     1180
#define IDC_COP2C29                     1181
#define IDC_COP2C30                     1182
#define IDC_COP2C31                     1183
#define IDC_BUTTON1                     1254
#define IDC_BIOSDIR                     1254
#define IDC_FORMAT1                     1254
#define IDC_ADDCODE                     1254
#define IDC_PLUGINSDIR                  1255
#define IDC_FORMAT2                     1255
#define IDC_LABEL_DATATYPE              1260
#define IDC_LABEL_SEARCHFOR             1261
#define IDC_LABEL_VALUE                 1262
#define IDC_LABEL_DATABASE              1263
#define IDC_WIDESCREEN                  1264
#define IDC_HIDECURSOR                  1265
#define ID_FILE_EXIT                    40001
#define ID_HELP_ABOUT                   40002
#define ID_FILE_RUN_CD                  40003
#define ID_FILE_RUN_EXE                 40004
#define ID_EMULATOR_PAUSE               40005
#define ID_EMULATOR_RESET               40006
#define ID_FILE_RUN_ISO                 40007
#define ID_DEBUG_ENABLE_DEBUGGER        40008
#define ID_CONFIGURATION_GRAPHICS       40009
#define ID_CONFIGURATION_SOUND          40010
#define ID_CONFIGURATION_CDROM          40011
#define ID_CONFIGURATION_MEMORYCARDMANAGER 40012
#define ID_CONFIGURATION_CPU            40013
#define ID_EMULATOR_RUN                 40014
#define ID_DEBUGREG                     40015
#define ID_DEBUG_MESSAGES               40015
#define ID_EMULATOR_SHUTDOWN            40015
#define ID_FILE_RUN_NOGUI               40016
#define ID_CONFIGURATION_CONTROLLERS    40017
#define ID_CONFIGURATION                40018
#define ID_CONFIGURATION_LINKCABLE      40019
#define ID_FILE_RUNBIOS                 40026
#define ID_CONFIGURATION_NETPLAY        40043
#define ID_EMULATOR_SWITCH_ISO          40044
#define ID_CONFIGURATION_CHEATLIST      40045
#define ID_CONFIGURATION_CHEATSEARCH    40046
#define ID_FILE_STATES_LOAD_SLOT1       40048
#define ID_FILE_STATES_LOAD_SLOT2       40049
#define ID_FILE_STATES_LOAD_SLOT3       40050
#define ID_FILE_STATES_LOAD_SLOT4       40051
#define ID_FILE_STATES_LOAD_SLOT5       40052
#define ID_FILE_STATES_LOAD_SLOT6       40053
#define ID_FILE_STATES_LOAD_SLOT7       40054
#define ID_FILE_STATES_LOAD_SLOT8       40055
#define ID_FILE_STATES_LOAD_SLOT9       40056
#define ID_FILE_STATES_LOAD_OTHER       40057
#define ID_FILE_STATES_SAVE_SLOT1       40058
#define ID_FILE_STATES_SAVE_SLOT2       40059
#define ID_FILE_STATES_SAVE_SLOT3       40060
#define ID_FILE_STATES_SAVE_SLOT4       40061
#define ID_FILE_STATES_SAVE_SLOT5       40062
#define ID_FILE_STATES_SAVE_SLOT6       40063
#define ID_FILE_STATES_SAVE_SLOT7       40064
#define ID_FILE_STATES_SAVE_SLOT8       40065
#define ID_FILE_STATES_SAVE_SLOT9       40066
#define ID_FILE_STATES_SAVE_OTHER       40067
#define ID_LANGS                        50000

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        116
#define _APS_NEXT_COMMAND_VALUE         40047
#define _APS_NEXT_CONTROL_VALUE         1054
#define _APS_NEXT_SYMED_VALUE           102
#endif
#endif
